<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>IncDecVolumeCommandLineOption</name>
    <message>
        <location filename="../incdecvolumeoption.cpp" line="44"/>
        <source>Increase volume with step 5</source>
        <translation>Збільшити гучність на 5 одиниць</translation>
    </message>
    <message>
        <location filename="../incdecvolumeoption.cpp" line="45"/>
        <source>Decrease volume with step 5</source>
        <translation>Зменшити гучність на 5 одиниць</translation>
    </message>
</context>
</TS>
